Module blaxel.core.client.models.last_n_requests_metric
=======================================================

Classes
-------

`LastNRequestsMetric(date: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, status_code: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workload_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workload_type: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Last N requests
    
    Attributes:
        date (Union[Unset, str]): Timestamp
        status_code (Union[Unset, str]): Status code
        workload_id (Union[Unset, str]): Workload ID
        workload_type (Union[Unset, str]): Workload type
        workspace (Union[Unset, str]): Workspace
    
    Method generated by attrs for class LastNRequestsMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `date: blaxel.core.client.types.Unset | str`
    :

    `status_code: blaxel.core.client.types.Unset | str`
    :

    `workload_id: blaxel.core.client.types.Unset | str`
    :

    `workload_type: blaxel.core.client.types.Unset | str`
    :

    `workspace: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :